@@ -2,9 +2,8 @@
 # Copyright (c) 2021-2023 Claudio Guarnieri.
 # Use of this software is governed by the MVT License 1.1 that can be found at
 #   https://license.mvt.re/1.1/
-from typing import Dict
 from logging import Logger
-from typing import Optional
+from typing import Dict, Optional
 
 import packaging
 
@@ -264,12 +263,16 @@ IPHONE_IOS_VERSIONS = [
     {"build": "19H117", "version": "15.7.1"},
     {"build": "19H218", "version": "15.7.2"},
     {"build": "20A362", "version": "16.0"},
+    {"build": "20A371", "version": "16.0.1"},
+    {"build": "20A380", "version": "16.0.2"},
+    {"build": "20A392", "version": "16.0.3"},
     {"build": "20B82", "version": "16.1"},
     {"build": "20B101", "version": "16.1.1"},
     {"build": "20B110", "version": "16.1.2"},
     {"build": "20C65", "version": "16.2"},
     {"build": "20D47", "version": "16.3"},
-    {"build": "20D67", "version": "16.3.1"}
+    {"build": "20D67", "version": "16.3.1"},
+    {"build": "20E247", "version": "16.4"}
 ]
 
 
